@@ -6,13 +6,13 @@ c         by putting  Es = 0.
      +  AnihiE, BackAngLimit, BaseErg, BasePower, BorderHeightH
      +, BorderHeightL, Cekaon, Ceneuc, Cepic0, Charge2heavyG
      +, Code2heavyG, Code2massN, Deltkp, Deltpip, Deltpp, Ecrit, Efermi
-     +, Elund, Elund2, Elund3, ErrorOut, Es, EthinRatio, EventNo
-     +, EventsInTheRun, ExactThick, FragmentTbl, Generate2
-     +, HeavyG2charge, HeavyG2code, HeavyG2massN, HeavyG2symbol
-     +, HowGeomag, HowIntNuc, IncreaseXsec, KEminObs2, Knockon, Kpicns
-     +, Kpilog, LpmBremEmin, LpmPairEmin, LundPara, MagBrem
-     +, MagBremEmin, MagChgDist, MagD, MagE, MagN, MagPair, MagPairEmin
-     +, MaxComptonE, MaxPhotoE, Mudirp, MulLow, NoOfSites2
+     +, Elund, Elund2, Elund3, EndLevel, EndLevel2, ErrorOut, Es
+     +, EthinRatio, EventNo, EventsInTheRun, ExactThick, FragmentTbl
+     +, Generate2, HeavyG2charge, HeavyG2code, HeavyG2massN
+     +, HeavyG2symbol, HowGeomag, HowIntNuc, IncreaseXsec, KEminObs2
+     +, Knockon, Kpicns, Kpilog, LpmBremEmin, LpmPairEmin, LundPara
+     +, MagBrem, MagBremEmin, MagChgDist, MagD, MagE, MagN, MagPair
+     +, MagPairEmin, MaxComptonE, MaxPhotoE, Mudirp, MulLow, NoOfSites2
      +, OffsetHeight, PathLimit, PrevEventNo, PtAvFrag, PtAvNonInteNuc
      +, RatioToE0, RecoilKineMinE, Reverse, SeedFileDev, SucPw, TempDev
      +, TraceDev, Truncc, Truncn, Truncx, UpsilonMin, X0
