@@ -128,6 +128,7 @@ c          save present conditions
          KEminObs2 = KEminObs
          Generate2 = Generate
          NoOfSites2 = NoOfSites
+         EndLevel2 = EndLevel
          if(Job .eq. ' ') then
                 !     no msg at all
          elseif(Job .eq. 'skeleton') then
@@ -153,15 +154,17 @@ c             from &Hparam
           call cerrorMsg(msg, 1)
           write(msg, *)  '      New Generate=', Generate
           call cerrorMsg(msg, 1)
-          if(NoOfSites .ne. NoOfSites2) then
+          if(EndLevel .gt. EndLevel2) then
 c                to deeper detph than skeleton
              write(msg, *)
      *        ' fleshing will be done to deeper depth than'//
      *        ' skeleton making time'
              call cerrorMsg(msg, 1)
-             write(msg, *) ' No of old levels=', NoOfSites2, 
-     *       ' No of new levels=', NoOfSites
+             write(msg, *) ' No of old levels=', EndLevel2,
+     *       ' No of new levels=', EndLevel
              call cerrorMsg(msg, 1)
+          elseif(EndLevel .lt. EndLevel2) then
+             call cerrorMsg('EndLevel must be >= skelton time', 0)
           endif
 c                open SeedFile
           write(msg, *) 'opening SeedFFile=', 
