@@ -187,28 +187,26 @@ c          energy / nucleon for heavy
          else
             ergpn = IncidentCopy.p.fm.p(4)
          endif
-         EminAS=max(1.d0, ergpn*RatioToE0)   ! if Ee < E0*RatioToE0 or 
-               ! if < 1 GeV, neglect AS generation
-               ! wait until electon  energy becomes < EasGen for a.s
+
+               ! wait until electon  energy becomes < EasWait for AS
                ! generation. WaitRatio < 1 should be used when 1ry is 
                ! g or e.   (say, 0.01)
-c         EasWait =max(ergpn * WaitRatio, EminAS*10.0)
-         EasWait =max(ergpn * WaitRatio, EminAS*100.0)   ! 95/08/17
+         EasWait =ergpn * WaitRatio
+         EminAS=min(ergpn*RatioToE0, EasWait) ! follow at least down to  this
+c                                    energy for hadronic interaction
       else
          EminAS = 1.d30
       endif
 
       emin = eminob
+      emCas = 1.d30
 
       if(obas) then
-c         emCas = min( EminAS, emin) 
-c         emin = emCas
-	  emin = min(EminAS, emin)     ! 95/0817/
-          emCas =min(max(1.d0, emin/30.), emin)   ! //
-      elseif(cas) then
-         emCas = emin
-      else
-         emCas = 1.d30
+	  emin = min(EminAS, emin)   
+          emCas =min(eminob, EasWait)
+      endif
+      if(cas) then
+         emCas =min(emin, EminAS)
       endif
 
 
