@@ -24,36 +24,41 @@ c           get one particle from stack
          if(moreptcl .eq. 0) goto 100   !  exit
          call rndsw(jold, 1)            !  specify 1st generator.
          call cifDead(TrackBefMove, icon)  ! generator may be switched to 2
-         if(icon .eq. 0) then
+c            AS generation. 
+
+c         if(icon .eq. 0) then
 c            thin sampling
             if(TrackBefMove.p.fm.p(4) .lt. Ethin) then
 c                do thin sampling
                iwgt = TrackBefMove.p.fm.p(4)/Ethin ! inverse weight
                call rndc(u)
                if(u .gt. iwgt) then
-                  icon =1       !  discard this ptcl
+                  icon =2       !  discard this ptcl
                else
                   TrackBefMove.wgt = TrackBefMove.wgt /iwgt
                endif
             endif    
-         endif
-c             AS generation. 
+c         endif
 
-         if(icon .eq. 0	) then
-	   if(ObserveAS .and. TrackBefMove.p.code .eq. kelec
-     *     .and.  TrackBefMove.asflag .eq. 0) then
-            if(TrackBefMove.p.fm.p(4) .le. EasWait) then
-c   95/08/17   if(TrackBefMove.p.fm.p(4) .ge. EminAS) then 
-	       if(TrackBefMove.p.fm.p(4) .gt. smallAS) then  ! 95/08/17
-                  call cobAS(TrackBefMove)
+         if(ObserveAS .and. icon .ne. 2) then
+            if(TrackBefMove.p.code .eq. kelec) then
+               if(TrackBefMove.asflag .eq. 0) then
+                  if(TrackBefMove.p.fm.p(4) .le. EasWait) then
+                     if(TrackBefMove.p.fm.p(4) .gt. smallAS) then ! 95/08/17
+                        call cobAS(TrackBefMove)
+                     endif
+                     TrackBefMove.asflag =1
+                  endif
+               endif
+            elseif(TrackBefMove.p.code .eq. kphoton) then
+               if(icon .ne. 0) then
+                  if(TrackBefMove.asflag .eq. 0) then
+                     if(TrackBefMove.p.fm.p(4) .gt. smallAS) then
+                        icon = 0 ! follow until it becomes e-pair
+                     endif
+                  endif
                endif
-               TrackBefMove.asflag =1
-c                   next 3 lines 95/08/17
-	       if(TrackBefMove.p.fm.p(4) .lt. KEminObs) then
-	          icon = 1
-               endif 
             endif
-          endif
          endif
 c        ----------------------------
          if(icon .eq. 0) then
@@ -138,7 +143,8 @@ c                  (at AS generation, some ptcl may have < KEminObs)
             endif
 c               update observation place
             MovedTrack.where = MovedTrack.where + 1
-            if(MovedTrack.where .le. NoOfSites) then
+c            if(MovedTrack.where .le. NoOfSites) then
+            if(MovedTrack.where .le. EndLevel) then  ! 96.09.18
 c                  if more obs-site, stack current ptcl.
                call cpush(MovedTrack)
             endif
